==> blesta-5.10.2.zip: blesta/language/ru_ru/navigation.php <==
<?php
/**
 * Navigation
 *
 * @package blesta
 * @subpackage blesta.language.ru_ru
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Navigation.getprimary.nav_tools_blacklist'] = 'Черный список';
$lang['Navigation.getsearchoptions.packages'] = 'Поиск пакетов';
$lang['Navigation.getsearchoptions.services'] = 'Поиск услуг';
$lang['Navigation.getsearchoptions.transactions'] = 'Поиск транзакций';
$lang['Navigation.getsearchoptions.invoices'] = 'Поиск счетов-фактур';
$lang['Navigation.getsearchoptions.clients'] = 'Поиск клиентов';
$lang['Navigation.getsearchoptions.smart'] = 'Интеллектуальный поиск';
$lang['Navigation.getsystem.nav_marketplace'] = 'Рынок';
$lang['Navigation.getsystem.nav_help_about'] = 'О Блесте';
$lang['Navigation.getsystem.nav_help_notes'] = 'Информация о выпуске';
$lang['Navigation.getsystem.nav_help_index'] = 'Ресурсы';
$lang['Navigation.getsystem.nav_help'] = 'Помощь';
$lang['Navigation.getsystem.nav_upgrade'] = 'Варианты модернизации';
$lang['Navigation.getsystem.nav_api'] = 'Доступ к API';
$lang['Navigation.getsystem.nav_staff_groups'] = 'Группы персонала';
$lang['Navigation.getsystem.nav_staff_manage'] = 'Управление персоналом';
$lang['Navigation.getsystem.nav_staff'] = 'Персонал';
$lang['Navigation.getsystem.nav_backup_amazon'] = 'Amazon S3';
$lang['Navigation.getsystem.nav_backup_index'] = 'По требованию';
$lang['Navigation.getsystem.nav_backup_ftp'] = 'Безопасный FTP';
$lang['Navigation.getsystem.nav_backup'] = 'Резервное копирование';
$lang['Navigation.getsystem.nav_companies'] = 'Компании';
$lang['Navigation.getsystem.nav_automation'] = 'Автоматизация';
$lang['Navigation.getsystem.nav_general_paymenttypes'] = 'Типы платежей';
$lang['Navigation.getsystem.nav_general_license'] = 'Лицензионный ключ';
$lang['Navigation.getsystem.nav_general_maintenance'] = 'Техническое обслуживание';
$lang['Navigation.getsystem.nav_general_geoip'] = 'Настройки GeoIP';
$lang['Navigation.getsystem.nav_general_basic'] = 'Базовая настройка';
$lang['Navigation.getsystem.nav_general'] = 'Общие сведения';
$lang['Navigation.getcompany.nav_feeds_settings'] = 'Настройки подачи';
$lang['Navigation.getcompany.nav_feeds_general'] = 'Общие сведения';
$lang['Navigation.getcompany.nav_feeds'] = 'Потоки данных';
$lang['Navigation.getcompany.nav_groups'] = 'Группы клиентов';
$lang['Navigation.getcompany.nav_plugins'] = 'Плагины';
$lang['Navigation.getcompany.nav_currency_active'] = 'Активные валюты';
$lang['Navigation.getcompany.nav_currency_currencysetup'] = 'Настройка валюты';
$lang['Navigation.getcompany.nav_currencies'] = 'Валюты';
$lang['Navigation.getcompany.nav_clientoptions_requiredfields'] = 'Обязательные поля клиента';
$lang['Navigation.getcompany.nav_clientoptions_customfields'] = 'Пользовательские поля клиента';
$lang['Navigation.getcompany.nav_clientoptions_general'] = 'Общие настройки клиента';
$lang['Navigation.getcompany.nav_clientoptions'] = 'Опции клиента';
$lang['Navigation.getcompany.nav_emails_signatures'] = 'Подписи';
$lang['Navigation.getcompany.nav_emails_templates'] = 'Шаблоны электронной почты';
$lang['Navigation.getcompany.nav_emails_mail'] = 'Настройки почты';
$lang['Navigation.getcompany.nav_emails'] = 'Электронные письма';
$lang['Navigation.getcompany.nav_taxes_taxrules'] = 'Налоговые правила';
$lang['Navigation.getcompany.nav_taxes_basictax'] = 'Основные настройки налогов';
$lang['Navigation.getcompany.nav_taxes'] = 'Налоги';
$lang['Navigation.getcompany.nav_gateways'] = 'Платежные шлюзы';
$lang['Navigation.getcompany.nav_messengers_templates'] = 'Шаблоны сообщений';
$lang['Navigation.getcompany.nav_messengers_configuration'] = 'Конфигурация мессенджера';
$lang['Navigation.getcompany.nav_messengers_messengers'] = 'Посланники';
$lang['Navigation.getcompany.nav_messengers'] = 'Посланники';
$lang['Navigation.getcompany.nav_modules'] = 'Модули';
$lang['Navigation.getcompany.nav_billing_acceptedtypes'] = 'Принимаемые типы платежей';
$lang['Navigation.getcompany.nav_billing_coupons'] = 'Купоны';
$lang['Navigation.getcompany.nav_billing_notices'] = 'Уведомления';
$lang['Navigation.getcompany.nav_billing_latefees'] = 'Плата за опоздание';
$lang['Navigation.getcompany.nav_billing_deliverymethods'] = 'Доставка счетов-фактур';
$lang['Navigation.getcompany.nav_billing_custominvoice'] = 'Настройка счетов-фактур';
$lang['Navigation.getcompany.nav_billing_invoices'] = 'Варианты выставления счетов и начислений';
$lang['Navigation.getcompany.nav_billing'] = 'Выставление счетов/оплата';
$lang['Navigation.getcompany.nav_automation'] = 'Автоматизация';
$lang['Navigation.getcompany.nav_lookandfeel_customize'] = 'Настроить';
$lang['Navigation.getcompany.nav_lookandfeel_actions'] = 'Действия';
$lang['Navigation.getcompany.nav_lookandfeel_navigation'] = 'Навигация';
$lang['Navigation.getcompany.nav_lookandfeel_layout'] = 'Макет';
$lang['Navigation.getcompany.nav_lookandfeel_template'] = 'Шаблон';
$lang['Navigation.getcompany.nav_lookandfeel_themes'] = 'Темы';
$lang['Navigation.getcompany.nav_lookandfeel'] = 'Внешний вид и ощущения';
$lang['Navigation.getcompany.nav_general_humanverification'] = 'Верификация человека';
$lang['Navigation.getcompany.nav_general_smart_search'] = 'Интеллектуальный поиск';
$lang['Navigation.getcompany.nav_general_marketing'] = 'Маркетинг';
$lang['Navigation.getcompany.nav_general_contacttypes'] = 'Типы контактов';
$lang['Navigation.getcompany.nav_general_encryption'] = 'Шифрование';
$lang['Navigation.getcompany.nav_general_international'] = 'Интернационализация';
$lang['Navigation.getcompany.nav_general_localization'] = 'Локализация';
$lang['Navigation.getcompany.nav_general'] = 'Общие сведения';
$lang['Navigation.getprimarypublic.nav_dashboard'] = 'Главная';
$lang['Navigation.getprimaryclient.nav_return'] = 'Вернуться к приборной панели';
$lang['Navigation.getprimaryclient.nav_contacts_add'] = 'Добавить контакт';
$lang['Navigation.getprimaryclient.nav_contacts'] = 'Контакты';
$lang['Navigation.getprimaryclient.nav_paymentaccounts_add'] = 'Добавить платежный счет';
$lang['Navigation.getprimaryclient.nav_paymentaccounts'] = 'Платежные счета';
$lang['Navigation.getprimaryclient.nav_services'] = 'Услуги';
$lang['Navigation.getprimaryclient.nav_dashboard'] = 'Приборная панель';
$lang['Navigation.getprimary.nav_settings_system'] = 'Система';
$lang['Navigation.getprimary.nav_settings_company'] = 'Компания';
$lang['Navigation.getprimary.nav_tools_renewals'] = 'Очередь на продление';
$lang['Navigation.getprimary.nav_tools_utilities'] = 'Утилиты';
$lang['Navigation.getprimary.nav_tools_currency'] = 'Конвертировать валюту';
$lang['Navigation.getprimary.nav_tools_logs'] = 'Журналы';
$lang['Navigation.getprimary.nav_tools'] = 'Инструменты';
$lang['Navigation.getprimary.nav_package_options'] = 'Настраиваемые опции';
$lang['Navigation.getprimary.nav_packages_groups'] = 'Группы пакетов';
$lang['Navigation.getprimary.nav_packages_browse'] = 'Просмотреть пакеты';
$lang['Navigation.getprimary.nav_packages'] = 'Пакеты';
$lang['Navigation.getprimary.nav_billing_batch'] = 'Партия';
$lang['Navigation.getprimary.nav_billing_printqueue'] = 'Очередь печати';
$lang['Navigation.getprimary.nav_billing_reports'] = 'Отчеты';
$lang['Navigation.getprimary.nav_billing_services'] = 'Услуги';
$lang['Navigation.getprimary.nav_billing_transactions'] = 'Транзакции';
$lang['Navigation.getprimary.nav_billing_quotations'] = 'Цитаты';
$lang['Navigation.getprimary.nav_billing_invoices'] = 'Счета-фактуры';
$lang['Navigation.getprimary.nav_billing_overview'] = 'Обзор';
$lang['Navigation.getprimary.nav_billing'] = 'Выставление счетов';
$lang['Navigation.getprimary.nav_clients_browse'] = 'Просмотреть клиентов';
$lang['Navigation.getprimary.nav_clients'] = 'Клиенты';
$lang['Navigation.getprimary.nav_home_dashboard'] = 'Приборная панель';
$lang['Navigation.getprimary.nav_home'] = 'Главная';
$lang['Navigation.!error.parent_id.valid'] = 'Неверный идентификатор родительского элемента навигации';
$lang['Navigation.!error.order.valid'] = 'Индекс заказа должен быть числовым значением';
$lang['Navigation.!error.action_id.valid'] = 'Неверный идентификатор действия';

==> blesta-5.11.4.zip: blesta/language/ru_ru/navigation.php <==
<?php
/**
 * Navigation
 *
 * @package blesta
 * @subpackage blesta.language.ru_ru
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Navigation.getprimary.nav_tools_blacklist'] = 'Черный список';
$lang['Navigation.getsearchoptions.packages'] = 'Поиск пакетов';
$lang['Navigation.getsearchoptions.services'] = 'Поиск услуг';
$lang['Navigation.getsearchoptions.transactions'] = 'Поиск транзакций';
$lang['Navigation.getsearchoptions.invoices'] = 'Поиск счетов-фактур';
$lang['Navigation.getsearchoptions.clients'] = 'Поиск клиентов';
$lang['Navigation.getsearchoptions.smart'] = 'Интеллектуальный поиск';
$lang['Navigation.getsystem.nav_marketplace'] = 'Рынок';
$lang['Navigation.getsystem.nav_help_about'] = 'О Блесте';
$lang['Navigation.getsystem.nav_help_notes'] = 'Информация о выпуске';
$lang['Navigation.getsystem.nav_help_index'] = 'Ресурсы';
$lang['Navigation.getsystem.nav_help'] = 'Помощь';
$lang['Navigation.getsystem.nav_upgrade'] = 'Варианты модернизации';
$lang['Navigation.getsystem.nav_api'] = 'Доступ к API';
$lang['Navigation.getsystem.nav_staff_groups'] = 'Группы персонала';
$lang['Navigation.getsystem.nav_staff_manage'] = 'Управление персоналом';
$lang['Navigation.getsystem.nav_staff'] = 'Персонал';
$lang['Navigation.getsystem.nav_backup_amazon'] = 'Amazon S3';
$lang['Navigation.getsystem.nav_backup_index'] = 'По требованию';
$lang['Navigation.getsystem.nav_backup_ftp'] = 'Безопасный FTP';
$lang['Navigation.getsystem.nav_backup'] = 'Резервное копирование';
$lang['Navigation.getsystem.nav_companies'] = 'Компании';
$lang['Navigation.getsystem.nav_automation'] = 'Автоматизация';
$lang['Navigation.getsystem.nav_general_paymenttypes'] = 'Типы платежей';
$lang['Navigation.getsystem.nav_general_license'] = 'Лицензионный ключ';
$lang['Navigation.getsystem.nav_general_maintenance'] = 'Техническое обслуживание';
$lang['Navigation.getsystem.nav_general_geoip'] = 'Настройки GeoIP';
$lang['Navigation.getsystem.nav_general_basic'] = 'Базовая настройка';
$lang['Navigation.getsystem.nav_general'] = 'Общие сведения';
$lang['Navigation.getcompany.nav_feeds_settings'] = 'Настройки подачи';
$lang['Navigation.getcompany.nav_feeds_general'] = 'Общие сведения';
$lang['Navigation.getcompany.nav_feeds'] = 'Потоки данных';
$lang['Navigation.getcompany.nav_groups'] = 'Группы клиентов';
$lang['Navigation.getcompany.nav_plugins'] = 'Плагины';
$lang['Navigation.getcompany.nav_currency_active'] = 'Активные валюты';
$lang['Navigation.getcompany.nav_currency_currencysetup'] = 'Настройка валюты';
$lang['Navigation.getcompany.nav_currencies'] = 'Валюты';
$lang['Navigation.getcompany.nav_clientoptions_requiredfields'] = 'Обязательные поля клиента';
$lang['Navigation.getcompany.nav_clientoptions_customfields'] = 'Пользовательские поля клиента';
$lang['Navigation.getcompany.nav_clientoptions_general'] = 'Общие настройки клиента';
$lang['Navigation.getcompany.nav_clientoptions'] = 'Опции клиента';
$lang['Navigation.getcompany.nav_emails_signatures'] = 'Подписи';
$lang['Navigation.getcompany.nav_emails_templates'] = 'Шаблоны электронной почты';
$lang['Navigation.getcompany.nav_emails_mail'] = 'Настройки почты';
$lang['Navigation.getcompany.nav_emails'] = 'Электронные письма';
$lang['Navigation.getcompany.nav_taxes_taxrules'] = 'Налоговые правила';
$lang['Navigation.getcompany.nav_taxes_basictax'] = 'Основные настройки налогов';
$lang['Navigation.getcompany.nav_taxes'] = 'Налоги';
$lang['Navigation.getcompany.nav_gateways'] = 'Платежные шлюзы';
$lang['Navigation.getcompany.nav_messengers_templates'] = 'Шаблоны сообщений';
$lang['Navigation.getcompany.nav_messengers_configuration'] = 'Конфигурация мессенджера';
$lang['Navigation.getcompany.nav_messengers_messengers'] = 'Посланники';
$lang['Navigation.getcompany.nav_messengers'] = 'Посланники';
$lang['Navigation.getcompany.nav_modules'] = 'Модули';
$lang['Navigation.getcompany.nav_billing_acceptedtypes'] = 'Принимаемые типы платежей';
$lang['Navigation.getcompany.nav_billing_coupons'] = 'Купоны';
$lang['Navigation.getcompany.nav_billing_notices'] = 'Уведомления';
$lang['Navigation.getcompany.nav_billing_latefees'] = 'Плата за опоздание';
$lang['Navigation.getcompany.nav_billing_deliverymethods'] = 'Доставка счетов-фактур';
$lang['Navigation.getcompany.nav_billing_custominvoice'] = 'Настройка счетов-фактур';
$lang['Navigation.getcompany.nav_billing_invoices'] = 'Варианты выставления счетов и начислений';
$lang['Navigation.getcompany.nav_billing'] = 'Выставление счетов/оплата';
$lang['Navigation.getcompany.nav_automation'] = 'Автоматизация';
$lang['Navigation.getcompany.nav_lookandfeel_customize'] = 'Настроить';
$lang['Navigation.getcompany.nav_lookandfeel_actions'] = 'Действия';
$lang['Navigation.getcompany.nav_lookandfeel_navigation'] = 'Навигация';
$lang['Navigation.getcompany.nav_lookandfeel_layout'] = 'Макет';
$lang['Navigation.getcompany.nav_lookandfeel_template'] = 'Шаблон';
$lang['Navigation.getcompany.nav_lookandfeel_themes'] = 'Темы';
$lang['Navigation.getcompany.nav_lookandfeel'] = 'Внешний вид и ощущения';
$lang['Navigation.getcompany.nav_general_humanverification'] = 'Верификация человека';
$lang['Navigation.getcompany.nav_general_smart_search'] = 'Интеллектуальный поиск';
$lang['Navigation.getcompany.nav_general_marketing'] = 'Маркетинг';
$lang['Navigation.getcompany.nav_general_contacttypes'] = 'Типы контактов';
$lang['Navigation.getcompany.nav_general_encryption'] = 'Шифрование';
$lang['Navigation.getcompany.nav_general_international'] = 'Интернационализация';
$lang['Navigation.getcompany.nav_general_localization'] = 'Локализация';
$lang['Navigation.getcompany.nav_general'] = 'Общие сведения';
$lang['Navigation.getprimarypublic.nav_dashboard'] = 'Главная';
$lang['Navigation.getprimaryclient.nav_return'] = 'Вернуться к приборной панели';
$lang['Navigation.getprimaryclient.nav_contacts_add'] = 'Добавить контакт';
$lang['Navigation.getprimaryclient.nav_contacts'] = 'Контакты';
$lang['Navigation.getprimaryclient.nav_paymentaccounts_add'] = 'Добавить платежный счет';
$lang['Navigation.getprimaryclient.nav_paymentaccounts'] = 'Платежные счета';
$lang['Navigation.getprimaryclient.nav_services'] = 'Услуги';
$lang['Navigation.getprimaryclient.nav_dashboard'] = 'Приборная панель';
$lang['Navigation.getprimary.nav_settings_system'] = 'Система';
$lang['Navigation.getprimary.nav_settings_company'] = 'Компания';
$lang['Navigation.getprimary.nav_tools_renewals'] = 'Очередь на продление';
$lang['Navigation.getprimary.nav_tools_utilities'] = 'Утилиты';
$lang['Navigation.getprimary.nav_tools_currency'] = 'Конвертировать валюту';
$lang['Navigation.getprimary.nav_tools_logs'] = 'Журналы';
$lang['Navigation.getprimary.nav_tools'] = 'Инструменты';
$lang['Navigation.getprimary.nav_package_options'] = 'Настраиваемые опции';
$lang['Navigation.getprimary.nav_packages_groups'] = 'Группы пакетов';
$lang['Navigation.getprimary.nav_packages_browse'] = 'Просмотреть пакеты';
$lang['Navigation.getprimary.nav_packages'] = 'Пакеты';
$lang['Navigation.getprimary.nav_billing_batch'] = 'Партия';
$lang['Navigation.getprimary.nav_billing_printqueue'] = 'Очередь печати';
$lang['Navigation.getprimary.nav_billing_reports'] = 'Отчеты';
$lang['Navigation.getprimary.nav_billing_services'] = 'Услуги';
$lang['Navigation.getprimary.nav_billing_transactions'] = 'Транзакции';
$lang['Navigation.getprimary.nav_billing_quotations'] = 'Цитаты';
$lang['Navigation.getprimary.nav_billing_invoices'] = 'Счета-фактуры';
$lang['Navigation.getprimary.nav_billing_overview'] = 'Обзор';
$lang['Navigation.getprimary.nav_billing'] = 'Выставление счетов';
$lang['Navigation.getprimary.nav_clients_browse'] = 'Просмотреть клиентов';
$lang['Navigation.getprimary.nav_clients'] = 'Клиенты';
$lang['Navigation.getprimary.nav_home_dashboard'] = 'Приборная панель';
$lang['Navigation.getprimary.nav_home'] = 'Главная';
$lang['Navigation.!error.parent_id.valid'] = 'Неверный идентификатор родительского элемента навигации';
$lang['Navigation.!error.order.valid'] = 'Индекс заказа должен быть числовым значением';
$lang['Navigation.!error.action_id.valid'] = 'Неверный идентификатор действия';
$lang['Navigation.getcompany.nav_html_templates'] = 'Шаблоны HTML';
$lang['Navigation.getprimary.nav_tools_provisioning'] = 'Очередь обслуживания';
